API docs for “spamfighter.plugins.test.test_null_partner_authorizer_provider.NullPartnerAuthorizerProviderTestCase”

# Class s.p.t.t.NullPartnerAuthorizerProviderTestCase(unittest.TestCase):

Part of spamfighter.plugins.test.test_null_partner_authorizer_provider View Source View In Hierarchy

Тест на `spamfighter.plugins.null_partner_authorizer_provider.NullPartnerAuthorizerProvider`.

Method | testInterface | Undocumented
Method | testGetAuthorizer | Undocumented

def testInterface(self): (source)
Undocumented
def testGetAuthorizer(self): (source)
Undocumented